==> promesa-1.1.2-20160502.193908-1.jar: _bluebird/externs.js <==
/**
 * @constructor
 */
var Promise = function() {};

/**
 * @this {Promise}
 * @return {null}
 */
Promise.prototype.config = function() {};

/**
 * @this {Promise}
 * @return {null}
 */
Promise.prototype.cancel = function() {};

/**
 * @this {Promise}
 * @return {Promise}
 */
Promise.prototype.finally = function() {};
/**
 * @this {Promise}
 * @return {Promise}
 */
Promise.prototype.then = function() {};

/**
 * @this {Promise}
 * @return {Promise}
 */
Promise.prototype.catch = function() {};

/**
 * @this {Promise}
 * @return {boolean}
 */
Promise.prototype.isRejected = function() {};

/**
 * @this {Promise}
 * @return {boolean}
 */
Promise.prototype.isFulfilled = function() {};

/**
 * @this {Promise}
 * @return {boolean}
 */
Promise.prototype.isPending = function() {};

/**
 * @this {Promise}
 * @return {object}
 */
Promise.prototype.value = function() {};

/**
 * @this {Promise}
 * @return {Error|object}
 */
Promise.prototype.reason = function() {};

/**
 * @this {Promise}
 * @return {Promise}
 */
Promise.prototype.timeout = function() {};

/**
 * @this {null}
 * @return {Promise}
 */
Promise.all = function() {};

/**
 * @this {null}
 * @return {Promise}
 */
Promise.any = function() {};

/**
 * @this {null}
 * @return {Promise}
 */
Promise.resolve = function() {};

/**
 * @this {null}
 * @return {Promise}
 */
Promise.reject = function() {};

/**
 * @this {null}
 * @return {Promise}
 */
Promise.delay = function() {};

/**
 * @this {null}
 * @return {Promise}
 */
Promise.noConflict = function() {};

==> promesa-1.3.1.jar: _bluebird/externs.js <==
/**
 * @constructor
 */
var Promise = function() {};

/**
 * @this {Promise}
 * @return {null}
 */
Promise.prototype.config = function() {};

/**
 * @this {Promise}
 * @return {null}
 */
Promise.prototype.cancel = function() {};

/**
 * @this {Promise}
 * @return {Promise}
 */
Promise.prototype.finally = function() {};
/**
 * @this {Promise}
 * @return {Promise}
 */
Promise.prototype.then = function() {};

/**
 * @this {Promise}
 * @return {Promise}
 */
Promise.prototype.catch = function() {};

/**
 * @this {Promise}
 * @return {Promise}
 */
Promise.prototype.spread = function() {};

/**
 * @this {Promise}
 * @return {Promise}
 */
Promise.prototype.bind = function() {};

/**
 * @this {Promise}
 * @return {boolean}
 */
Promise.prototype.isRejected = function() {};

/**
 * @this {Promise}
 * @return {boolean}
 */
Promise.prototype.isFulfilled = function() {};

/**
 * @this {Promise}
 * @return {boolean}
 */
Promise.prototype.isPending = function() {};

/**
 * @this {Promise}
 * @return {object}
 */
Promise.prototype.value = function() {};

/**
 * @this {Promise}
 * @return {Error|object}
 */
Promise.prototype.reason = function() {};

/**
 * @this {Promise}
 * @return {Promise}
 */
Promise.prototype.delay = function() {};

/**
 * @this {Promise}
 * @return {Promise}
 */
Promise.prototype.timeout = function() {};

/**
 * @this {Promise}
 * @return {Promise}
 */
Promise.prototype.all = function() {};

/**
 * @this {Promise}
 * @return {Promise}
 */
Promise.prototype.props = function() {};

/**
 * @this {Promise}
 * @return {Promise}
 */
Promise.prototype.any = function() {};

/**
 * @this {Promise}
 * @return {Promise}
 */
Promise.prototype.some = function() {};

/**
 * @this {Promise}
 * @return {Promise}
 */
Promise.prototype.map = function() {};

/**
 * @this {Promise}
 * @return {Promise}
 */
Promise.prototype.reduce = function() {};

/**
 * @this {Promise}
 * @return {Promise}
 */
Promise.prototype.filter = function() {};

/**
 * @this {Promise}
 * @return {Promise}
 */
Promise.prototype.each = function() {};

/**
 * @this {Promise}
 * @return {Promise}
 */
Promise.prototype.mapSeries = function() {};

/**
 * @this {Promise}
 * @return {Promise}
 */
Promise.prototype.asCallback = function() {};

/**
 * @this {Promise}
 * @return {Promise}
 */
Promise.prototype.tap = function() {};

/**
 * @this {Promise}
 * @return {Promise}
 */
Promise.prototype.call = function() {};

/**
 * @this {Promise}
 * @return {Promise}
 */
Promise.prototype.get = function() {};

/**
 * @this {Promise}
 * @return {Promise}
 */
Promise.prototype.return = function() {};

/**
 * @this {Promise}
 * @return {Promise}
 */
Promise.prototype.throw = function() {};

/**
 * @this {Promise}
 * @return {Promise}
 */
Promise.prototype.catchReturn = function() {};

/**
 * @this {Promise}
 * @return {Promise}
 */
Promise.prototype.catchThrow = function() {};

/**
 * @this {null}
 * @return {Promise}
 */
Promise.all = function() {};

/**
 * @this {null}
 * @return {Promise}
 */
Promise.props = function() {};

/**
 * @this {null}
 * @return {Promise}
 */
Promise.any = function() {};

/**
 * @this {null}
 * @return {Promise}
 */
Promise.some = function() {};

/**
 * @this {null}
 * @return {Promise}
 */
Promise.map = function() {};

/**
 * @this {null}
 * @return {Promise}
 */
Promise.reduce = function() {};

/**
 * @this {null}
 * @return {Promise}
 */
Promise.filter = function() {};

/**
 * @this {null}
 * @return {Promise}
 */
Promise.each = function() {};

/**
 * @this {null}
 * @return {Promise}
 */
Promise.mapSeries = function() {};

/**
 * @this {null}
 * @return {Promise}
 */
Promise.race = function() {};

/**
 * @this {null}
 * @return {Promise}
 */
Promise.resolve = function() {};

/**
 * @this {null}
 * @return {Promise}
 */
Promise.reject = function() {};

/**
 * @this {null}
 * @return {Promise}
 */
Promise.delay = function() {};

/**
 * @this {null}
 * @return {Promise}
 */
Promise.noConflict = function() {};

/**
 * @this {null}
 * @return {Promise}
 */
Promise.try = function() {};

/**
 * @this {null}
 * @return {Promise}
 */
Promise.attempt = function() {};

/**
 * @this {null}
 * @return {Promise}
 */
Promise.join = function() {};

/**
 * @this {null}
 * @return {Function}
 */
Promise.method = function() {};

/**
 * @this {null}
 * @return {Function}
 */
Promise.promisify = function() {};

/**
 * @this {null}
 * @return {Object}
 */
Promise.promisifyAll = function() {};

/**
 * @this {null}
 * @return {Promise}
 */
Promise.fromCallback = function() {};

/**
 * @this {null}
 * @return {Function}
 */
Promise.fromNode = function() {};
